# Amino.fix.fix

Fork of Amino.fix to improve this library.

## How to install?

`pip install amino.fix.fix`

## API Reference

[Read the Docs Link](https://aminopy.readthedocs.io/en/latest/)

## Warning

- Subclients are created a bit different way, please check source code and figure out, how to do it
- Requests -> Httpx, i think its better
- lib/util -> lib/ (why lib was empty?)
